@@ -42,9 +42,9 @@ $^V eq v5.8.3
 #
 ## Package name      : perl5
 ## Source directory  : .
-## Configuration time: Thu Dec 18 15:22:50 EET 2008
+## Configuration time: Wed Sep  1 15:54:55 EEST 2010
 ## Configured by     : Debian Project
-## Target system     : linux ngsw-bifh-06 2.6.18-6-amd64 #1 smp mon oct 13 18:13:07 utc 2008 arm gnulinux 
+## Target system     : linux hebifh023 2.6.32-5-amd64 #1 smp tue jun 1 06:11:58 utc 2010 arm gnulinux 
 #
 ## Configure command line arguments.
 #PERL_PATCHLEVEL=
@@ -103,7 +103,7 @@ installprivlib='/usr/share/perl/5.8'
 libpth='/usr/local/lib /lib /usr/lib'
 libs='-lgdbm -lgdbm_compat -ldl -lm -lpthread -lc -lcrypt'
 osname='linux'
-osvers='2.6.18-6-amd64'
+osvers='2.6.32-5-amd64'
 prefix='/usr'
 privlibexp='/usr/share/perl/5.8'
 sharpbang='#!'
@@ -139,7 +139,7 @@ afs='false'
 afsroot='/afs'
 alignbytes='8'
 ansi2knr=''
-aphostname='/scratchbox/tools/bin/hostname'
+aphostname='/scratchbox/tools/bin/uname -n'
 api_revision='5'
 api_subversion='0'
 api_version='8'
@@ -168,7 +168,7 @@ ccsymbols=''
 ccversion=''
 cf_by='Debian Project'
 cf_email='perl@packages.debian.org'
-cf_time='Thu Dec 18 15:22:50 EET 2008'
+cf_time='Wed Sep  1 15:54:55 EEST 2010'
 charsize='1'
 chgrp=''
 chmod='chmod'
@@ -496,8 +496,8 @@ d_seekdir='define'
 d_select='define'
 d_sem='define'
 d_semctl='define'
-d_semctl_semid_ds='undef'
-d_semctl_semun='undef'
+d_semctl_semid_ds='define'
+d_semctl_semun='define'
 d_semget='define'
 d_semop='define'
 d_sendmsg='define'
@@ -892,7 +892,7 @@ mv=''
 myarchname='arm-linux'
 mydomain=''
 myhostname='localhost'
-myuname='linux ngsw-bifh-06 2.6.18-6-amd64 #1 smp mon oct 13 18:13:07 utc 2008 arm gnulinux '
+myuname='linux hebifh023 2.6.32-5-amd64 #1 smp tue jun 1 06:11:58 utc 2010 arm gnulinux '
 n='-n'
 need_va_copy='undef'
 netdb_hlen_type='size_t'
@@ -931,7 +931,7 @@ perladmin='root@localhost'
 perllibs='-ldl -lm -lpthread -lc -lcrypt'
 perlpath='/usr/bin/perl'
 pg='pg'
-phostname='hostname'
+phostname='uname -n'
 pidtype='pid_t'
 plibpth=''
 pm_apiversion='5.005'
@@ -1307,7 +1307,7 @@ tie %Config, 'Config', {
     'libpth' => '/usr/local/lib /lib /usr/lib',
     'libs' => '-lgdbm -lgdbm_compat -ldl -lm -lpthread -lc -lcrypt',
     'osname' => 'linux',
-    'osvers' => '2.6.18-6-amd64',
+    'osvers' => '2.6.32-5-amd64',
     'prefix' => '/usr',
     'privlibexp' => '/usr/share/perl/5.8',
     'sharpbang' => '#!',
